@@ -10,7 +10,13 @@ class Extract(Step):
         self.step = "Ex"
         self.paramsFile = 'Extract.properties'
         self.logger = 'logExtract'
-        self.logFile =self.getRelativeFile(os.getcwd() +'\../logs/Extract.log')       
+        self.logFile =self.getRelativeFile(os.getcwd() +'\../logs/Extract.log') 
+
+    def startup(self):
+        return super().startup()
+
+    def doWork(self):
+        pass
 
     def storeToRedisSortedSet(self, key, score, data):
         jsonObj ={}
