@@ -10,6 +10,7 @@ import os
 import sys
 import traceback
 import requests
+import platform
 
 
 class Step:
@@ -33,7 +34,7 @@ class Step:
         self.setTaskID()
         self.setUUID()
         self.params = self.loadParams(self.paramsFile)
-        self.nextstep = self.params["nextstep"].data
+        self.nextStep = self.params["nextStep"].data
         self.setTaskExecutionID()
         self.startRedisConn()
         self.setLogger(self.logger, self.logFile, logging.INFO)
@@ -52,6 +53,11 @@ class Step:
     def setTaskExecutionID(self):
         self.taskExecutionID = self.taskID + "_" + self.startTime
 
+
+    # Get the NodeId of the System. Similar to uname -n
+    def getNodeId(self):
+        return platform.node()
+
     # Create  Redis connection
     def startRedisConn(self):
         self.rC = self.makeRedisConn()
@@ -64,6 +70,10 @@ class Step:
             configs.load(config_file)
             config_file.close()
         return configs
+    
+    def startSubscriber(self):
+        self.subscriber = self.rC.pubsub()
+        self.subscriber.subscribe(self.taskID + "_" + self.step)
 
     # declaring Redis connection parameters
     def makeRedisConn(self):
@@ -75,7 +85,7 @@ class Step:
             response = connection.ping()
             return connection
         except (redis.exceptions.ConnectionError, ConnectionRefusedError):
-            self.getLogger().error(self.logMessageFormat(self.step, inspect.stack()[0][3], 'Error in redis connection setup'))
+            self.logError(self.step, 'Error in redis connection setup')
 
     # Extracting UUID from path of current working directory
     def setUUID(self):
@@ -86,7 +96,7 @@ class Step:
     def setTaskID(self):
         with open(self.getRelativeFile( os.getcwd() +'\../params/Identifier.txt')) as f:
             lines = f.readlines()
-        self.taskID = "BATCH_MULTISOURCE_AAPL"
+        self.taskID = lines[0]
         f.close()
 
     # Storing the datahandoff in a dataframe and the converting  DF to json and printing it
@@ -110,13 +120,13 @@ class Step:
     def getLogger(self):
         return self.mylogger
 
-    def logMessageFormat(self, fileName, method, message):
+    def logMessageFormat(self, step, method, message):
         try:
-            if message == None or fileName == None or method == None:
+            if message == None or step == None or method == None:
                 logdata = ' : ' + 'None'
                 return logdata
             else:
-                logdata = ' : ' + self.taskExecutionID + ' : ' + fileName + ' : ' + method + ' : ' + message
+                logdata = ' : ' + self.taskExecutionID + ' : ' + step + ' : ' + method + ' : ' + message
                 return logdata
         except:
             print('logMessageFormat')
@@ -125,15 +135,15 @@ class Step:
     def exceptionTraceback(self):
         try:
             # Get current system exception
-            ex_traceback = sys.exc_info()
+            # sys.exc_info() returns list of size 3 automatic assignments to variables
+            ex_type, ex_value, ex_traceback = sys.exc_info()
             # Extract unformatter stack traces as tuples
-            # trace_back = traceback.extract_tb(ex_traceback)
+            trace_back = traceback.extract_tb(ex_traceback)
             # Format stacktrace
-            stack_trace = ''
-            # stack_trace = list()
-            # print(trace_back)
-            # for trace in trace_back:
-            #     stack_trace.append("File : %s , Line : %d, Message : %s" % (trace[0], trace[1], trace[3]))
+            stack_trace = list()
+            for trace in trace_back:
+                stack_trace.append("File : %s , Line : %d, Message : %s" % (trace[0], trace[1], trace[3]))
+            # self.getLogger().error(self.logMessageFormat(self.step, inspect.stack()[0][3], str(str(ex_traceback) + ' ' + str(stack_trace))))
             return str(str(ex_traceback) + ' ' + str(stack_trace))
         except Exception as error:
             print('#######exceptionTraceback#### ' + str(error))
@@ -147,11 +157,11 @@ class Step:
             if key in responseData:
                 return responseData[key]
             else:
-                self.getLogger().error(self.logMessageFormat(self.step, inspect.stack()[0][3], 'Key not found' + key))
+                self.logError(self.step, 'Key not found' + key)
                 print('Key not found' + key)
                 return None
         except(BaseException) as e:
-            self.getLogger().error(self.logMessageFormat(self.step, inspect.stack()[0][3], str(e)))
+            self.logError(self.step, str(e))
             print(self.exceptionTraceback())
             return None
 
@@ -161,11 +171,41 @@ class Step:
             if response.status_code == successResponse:
                 return response
             else:
-                self.getLogger().error(self.logMessageFormat(self.step, inspect.stack()[0][3],
-                                                             'response.status_code from createAndGetResponseFromURL ' + str(
-                                                                 response.status_code)))
+                self.logError(self.step, 'response.status_code from createAndGetResponseFromURL ' + str(response.status_code))
                 return None
         except(BaseException) as e:
-            self.getLogger().error(self.logMessageFormat(self.step, inspect.stack()[0][3], str(e)))
+            self.logError(self.step, str(e))
             print(self.exceptionTraceback())
             return None
+
+
+    def logInfo(self, step, message):
+        currentframe = inspect.currentframe()
+        outerFrames = inspect.getouterframes(currentframe, 2)
+        self.getLogger().info(self.logMessageFormat(step, outerFrames[1][3], message))
+
+
+    def logWarn(self, step, message):
+        currentframe = inspect.currentframe()
+        outerFrames = inspect.getouterframes(currentframe, 2)
+        self.getLogger().warn(self.logMessageFormat(step, outerFrames[1][3], message))
+
+
+    def logError(self, step, message):
+        currentframe = inspect.currentframe()
+        outerFrames = inspect.getouterframes(currentframe, 2)
+        self.getLogger().error(self.logMessageFormat(step, outerFrames[1][3], message))
+
+
+    def logDebug(self, step, message):
+        currentframe = inspect.currentframe()
+        outerFrames = inspect.getouterframes(currentframe, 2)
+        self.getLogger().debug(self.logMessageFormat(step, outerFrames[1][3], message))
+
+
+    def logFatal(self, step, message):
+        currentframe = inspect.currentframe()
+        outerFrames = inspect.getouterframes(currentframe, 2)
+        self.getLogger().fatal(self.logMessageFormat(step, outerFrames, message))
+
+        
